Downloads R5.jar and saves it locally, inside the package directory.
download_r5(
version = NULL,
quiet = FALSE,
force_update = FALSE,
temp_dir = FALSE
)A string. The version of R5 to be downloaded. When NULL, it
defaults to the latest version.
A logical. Whether to show informative messages when downloading
the file. Defaults to FALSE.
A logical. Whether to overwrite a previously downloaded
R5.jar in the local directory. Defaults to FALSE.
A logical. Whether the file should be saved in a temporary
directory. Defaults to FALSE.
The path to the downloaded file.
Other Build network:
build_network(),
setup_r5()