Sets up Java logging for r5r and ensures Java SE Development Kit 21 is installed.
start_r5r_java(data_path, temp_dir = FALSE, verbose = FALSE)No return value. The function will stop execution with an error if Java 21 is not found.
This function initializes the Java Virtual Machine (JVM) with a log path for r5r, and checks that the installed Java version is 21. If not, it stops with an informative error message and download links.
Other support functions:
exists_tiff(),
fileurl_from_metadata(),
get_gtfs_errors(),
stop_r5(),
tempdir_unique(),
travel_time_surface(),
validate_bad_osm_ids()