Skip to contents

Stops the given r5r_network objects, or all r5r_network objects in the calling environment if none is supplied.

Usage

stop_r5(...)

Arguments

...

r5r_network objects currently running. By default, if no r5r network is supplied all running networks are stopped.

Value

No return value, called for side effects.

Examples

library(r5r)

path <- system.file("extdata/poa", package = "r5r")

r5r_network <- build_network(path)
#> Using cached R5 version from /home/runner/.cache/R/r5r/r5_jar_v7.5.1/r5-v7.5-1-gf3631e9-all.jar
#> ℹ Using cached network from
#>   /home/runner/work/_temp/Library/r5r/extdata/poa/network.dat.

stop_r5(r5r_network)
#> r5r_network has been successfully stopped.