Skip to contents

This returns a data frame of GTFS errors R5 encountered when building the network. You can call this with the network itself as the main parameter. If network build fails, you won't have a network object, so you can also call this with the data_path to where the network is stored.

Usage

get_gtfs_errors(r5r_network)

Arguments

r5r_network

the R5R network object, or a path to the location where the network is stored (useful if network build failed).

Value

A data.frame

Examples

library(r5r)

# directory with street network and gtfs files
data_path <- system.file("extdata/poa", package = "r5r")
r5r_network <- build_network(data_path)
#>  Using cached network from
#>   /home/runner/work/_temp/Library/r5r/extdata/poa/network.dat.

get_gtfs_errors(r5r_network)
#> Empty data.table (0 rows and 6 cols): file,line,type,field,id,priority