Get GTFS eventual errors encountered in network building
Source:R/get_gtfs_errors.R
get_gtfs_errors.RdThis returns a data frame of GTFS errors R5 encountered when building the
network. You can call this with the network itself as the main parameter. If
network build fails, you won't have a network object, so you can also call
this with the data_path to where the network is stored.
See also
Other support functions:
exists_tiff(),
fileurl_from_metadata(),
start_r5r_java(),
stop_r5(),
tempdir_unique(),
travel_time_surface,
validate_bad_osm_ids()
Examples
library(r5r)
# directory with street network and gtfs files
data_path <- system.file("extdata/poa", package = "r5r")
r5r_network <- build_network(data_path)
#> ℹ Using cached network from
#> /home/runner/work/_temp/Library/r5r/extdata/poa/network.dat.
get_gtfs_errors(r5r_network)
#> Empty data.table (0 rows and 6 cols): file,line,type,field,id,priority